@@ -1,6 +1,7 @@
 package policy
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"strings"
@@ -101,7 +102,7 @@ type RoleModificationOptions struct {
 	Groups   []string
 	Subjects []rbacv1.Subject
 
-	DryRun bool
+	DryRunStrategy kcmdutil.DryRunStrategy
 
 	PrintErrf func(format string, args ...interface{})
 
@@ -332,7 +333,11 @@ func (o *RoleModificationOptions) innerComplete(f kcmdutil.Factory, cmd *cobra.C
 		return err
 	}
 
-	o.DryRun = kcmdutil.GetFlagBool(cmd, "dry-run")
+	o.DryRunStrategy, err = kcmdutil.GetDryRunStrategy(cmd)
+	if err != nil {
+		return err
+	}
+
 	o.PrintErrf = func(format string, args ...interface{}) {
 		fmt.Fprintf(o.ErrOut, format, args...)
 	}
@@ -385,7 +390,7 @@ func (o *RoleModificationOptions) CompleteUserWithSA(f kcmdutil.Factory, cmd *co
 	}
 
 	o.ToPrinter = func(operation string) (printers.ResourcePrinter, error) {
-		o.PrintFlags.NamePrintFlags.Operation = getSuccessMessage(o.DryRun, operation, o.Targets)
+		o.PrintFlags.NamePrintFlags.Operation = getRolesSuccessMessage(o.DryRunStrategy, operation, o.Targets)
 		return o.PrintFlags.ToPrinter()
 	}
 
@@ -407,7 +412,7 @@ func (o *RoleModificationOptions) Complete(f kcmdutil.Factory, cmd *cobra.Comman
 	}
 
 	o.ToPrinter = func(operation string) (printers.ResourcePrinter, error) {
-		o.PrintFlags.NamePrintFlags.Operation = getSuccessMessage(o.DryRun, operation, o.Targets)
+		o.PrintFlags.NamePrintFlags.Operation = getRolesSuccessMessage(o.DryRunStrategy, operation, o.Targets)
 		return o.PrintFlags.ToPrinter()
 	}
 
@@ -508,9 +513,9 @@ func (o *RoleModificationOptions) AddRole() error {
 	if o.PrintErrf != nil {
 		var err error
 		if roleBinding.RoleKind() == "Role" {
-			_, err = o.RbacClient.Roles(o.RoleBindingNamespace).Get(roleBinding.RoleName(), metav1.GetOptions{})
+			_, err = o.RbacClient.Roles(o.RoleBindingNamespace).Get(context.TODO(), roleBinding.RoleName(), metav1.GetOptions{})
 		} else {
-			_, err = o.RbacClient.ClusterRoles().Get(roleBinding.RoleName(), metav1.GetOptions{})
+			_, err = o.RbacClient.ClusterRoles().Get(context.TODO(), roleBinding.RoleName(), metav1.GetOptions{})
 		}
 		if err != nil && kapierrors.IsNotFound(err) {
 			o.PrintErrf("Warning: role '%s' not found\n", roleBinding.RoleName())
@@ -526,15 +531,15 @@ func (o *RoleModificationOptions) AddRole() error {
 			switch newSubject.Kind {
 			case rbacv1.ServiceAccountKind:
 				if o.ServiceAccountClient != nil {
-					_, err = o.ServiceAccountClient.ServiceAccounts(newSubject.Namespace).Get(newSubject.Name, metav1.GetOptions{})
+					_, err = o.ServiceAccountClient.ServiceAccounts(newSubject.Namespace).Get(context.TODO(), newSubject.Name, metav1.GetOptions{})
 				}
 			case rbacv1.UserKind:
 				if o.UserClient != nil {
-					_, err = o.UserClient.Users().Get(newSubject.Name, metav1.GetOptions{})
+					_, err = o.UserClient.Users().Get(context.TODO(), newSubject.Name, metav1.GetOptions{})
 				}
 			case rbacv1.GroupKind:
 				if o.UserClient != nil {
-					_, err = o.UserClient.Groups().Get(newSubject.Name, metav1.GetOptions{})
+					_, err = o.UserClient.Groups().Get(context.TODO(), newSubject.Name, metav1.GetOptions{})
 				}
 			}
 			if err != nil && kapierrors.IsNotFound(err) {
@@ -544,7 +549,7 @@ func (o *RoleModificationOptions) AddRole() error {
 	}
 	roleBinding.SetSubjects(newSubjects)
 
-	if o.DryRun || (o.PrintFlags.OutputFormat != nil && len(*o.PrintFlags.OutputFormat) > 0) {
+	if o.DryRunStrategy == kcmdutil.DryRunClient {
 		return p.PrintObj(roleBinding.Object(), o.Out)
 	}
 
@@ -595,7 +600,7 @@ func (o *RoleModificationOptions) checkRolebindingAutoupdate(roleBinding *roleBi
 			o.PrintErrf("Warning: Your changes may get lost whenever a master"+
 				" is restarted, unless you prevent reconciliation of this"+
 				" rolebinding using the following command: oc annotate"+
-				" %s.rbac %s '%s=false' --overwrite", roleBinding.Type(),
+				" %s.rbac %s '%s=false' --overwrite\n", roleBinding.Type(),
 				roleBinding.Name(), rbacv1.AutoUpdateAnnotationKey)
 		}
 	}
@@ -675,46 +680,26 @@ func (o *RoleModificationOptions) RemoveRole() error {
 			return fmt.Errorf("unable to find target %v", o.Targets)
 		}
 
-		var updated *unstructured.UnstructuredList
-		if len(o.RoleBindingNamespace) > 0 {
-			updatedBindings := &unstructured.UnstructuredList{
-				Object: map[string]interface{}{
-					"kind":       "List",
-					"apiVersion": "v1",
-					"metadata":   map[string]interface{}{},
-				},
+		updatedBindings := &unstructured.UnstructuredList{
+			Object: map[string]interface{}{
+				"kind":       "List",
+				"apiVersion": "v1",
+				"metadata":   map[string]interface{}{},
+			},
+		}
+		for _, binding := range roleBindings {
+			obj, err := runtime.DefaultUnstructuredConverter.ToUnstructured(binding.Object())
+			if err != nil {
+				return err
 			}
-			for _, binding := range roleBindings {
-				obj, err := runtime.DefaultUnstructuredConverter.ToUnstructured(binding.Object())
-				if err != nil {
-					return err
-				}
-				updatedBindings.Items = append(updatedBindings.Items, unstructured.Unstructured{Object: obj})
-			}
-			updated = updatedBindings
-		} else {
-			updatedBindings := &unstructured.UnstructuredList{
-				Object: map[string]interface{}{
-					"kind":       "List",
-					"apiVersion": "v1",
-					"metadata":   map[string]interface{}{},
-				},
-			}
-			for _, binding := range roleBindings {
-				obj, err := runtime.DefaultUnstructuredConverter.ToUnstructured(binding.Object())
-				if err != nil {
-					return err
-				}
-				updatedBindings.Items = append(updatedBindings.Items, unstructured.Unstructured{Object: obj})
-			}
-			updated = updatedBindings
+			updatedBindings.Items = append(updatedBindings.Items, unstructured.Unstructured{Object: obj})
 		}
 
-		return p.PrintObj(updated, o.Out)
+		return p.PrintObj(updatedBindings, o.Out)
 	}
 
 	roleToPrint := o.roleObjectToPrint()
-	if o.DryRun {
+	if o.DryRunStrategy == kcmdutil.DryRunClient {
 		return p.PrintObj(roleToPrint, o.Out)
 	}
 
@@ -758,12 +743,12 @@ existingLoop:
 	return newSubjects, found
 }
 
-func getSuccessMessage(dryRun bool, operation string, targets []string) string {
+func getRolesSuccessMessage(dryRunStrategy kcmdutil.DryRunStrategy, operation string, targets []string) string {
 	allTargets := fmt.Sprintf("%q", targets)
 	if len(targets) == 1 {
 		allTargets = fmt.Sprintf("%q", targets[0])
 	}
-	if dryRun {
+	if dryRunStrategy == kcmdutil.DryRunClient {
 		return fmt.Sprintf("%s: %s (dry run)", operation, allTargets)
 	}
 	return fmt.Sprintf("%s: %s", operation, allTargets)
