@@ -1,12 +1,14 @@
 package app
 
 import (
+	"context"
 	"fmt"
 	"regexp"
 	"sort"
 	"strings"
 
 	kappsv1 "k8s.io/api/apps/v1"
+	kappsv1beta1 "k8s.io/api/apps/v1beta1"
 	kappsv1beta2 "k8s.io/api/apps/v1beta2"
 	corev1 "k8s.io/api/core/v1"
 	extensionsv1beta1 "k8s.io/api/extensions/v1beta1"
@@ -174,19 +176,20 @@ type Pipeline struct {
 	Name string
 	From string
 
-	InputImage *ImageRef
-	Build      *BuildRef
-	Image      *ImageRef
-	Deployment *DeploymentConfigRef
-	Labels     map[string]string
+	InputImage       *ImageRef
+	Build            *BuildRef
+	Image            *ImageRef
+	Deployment       *DeploymentRef
+	DeploymentConfig *DeploymentConfigRef
+	Labels           map[string]string
 }
 
-// NeedsDeployment sets the pipeline for deployment.
-func (p *Pipeline) NeedsDeployment(env Environment, labels map[string]string, asTest bool) error {
+// NeedsDeploymentConfig sets the pipeline for deploymentconfig.
+func (p *Pipeline) NeedsDeploymentConfig(env Environment, labels map[string]string, asTest bool) error {
 	if p.Deployment != nil {
 		return nil
 	}
-	p.Deployment = &DeploymentConfigRef{
+	p.DeploymentConfig = &DeploymentConfigRef{
 		Name: p.Name,
 		Images: []*ImageRef{
 			p.Image,
@@ -198,6 +201,22 @@ func (p *Pipeline) NeedsDeployment(env Environment, labels map[string]string, as
 	return nil
 }
 
+// NeedsDeployment sets the pipeline for deployment.
+func (p *Pipeline) NeedsDeployment(env Environment, labels map[string]string, asTest bool) error {
+	if p.Deployment != nil {
+		return nil
+	}
+	p.Deployment = &DeploymentRef{
+		Name: p.Name,
+		Images: []*ImageRef{
+			p.Image,
+		},
+		Env:    env,
+		Labels: labels,
+	}
+	return nil
+}
+
 // Objects converts all the components in the pipeline into runtime objects.
 func (p *Pipeline) Objects(accept, objectAccept Acceptor) (Objects, error) {
 	objects := Objects{}
@@ -256,7 +275,16 @@ func (p *Pipeline) Objects(accept, objectAccept Acceptor) (Objects, error) {
 		}
 	}
 	if p.Deployment != nil && accept.Accept(p.Deployment) {
-		dc, err := p.Deployment.DeploymentConfig()
+		dc, err := p.Deployment.Deployment()
+		if err != nil {
+			return nil, err
+		}
+		if objectAccept.Accept(dc) {
+			objects = append(objects, dc)
+		}
+	}
+	if p.DeploymentConfig != nil && accept.Accept(p.DeploymentConfig) {
+		dc, err := p.DeploymentConfig.DeploymentConfig()
 		if err != nil {
 			return nil, err
 		}
@@ -272,17 +300,17 @@ type PipelineGroup []*Pipeline
 
 // Reduce squashes all common components from the pipelines.
 func (g PipelineGroup) Reduce() error {
-	var deployment *DeploymentConfigRef
+	var deploymentConfig *DeploymentConfigRef
 	for _, p := range g {
-		if p.Deployment == nil || p.Deployment == deployment {
+		if p.DeploymentConfig == nil || p.DeploymentConfig == deploymentConfig {
 			continue
 		}
-		if deployment == nil {
-			deployment = p.Deployment
+		if deploymentConfig == nil {
+			deploymentConfig = p.DeploymentConfig
 		} else {
-			deployment.Images = append(deployment.Images, p.Deployment.Images...)
-			deployment.Env = NewEnvironment(deployment.Env, p.Deployment.Env)
-			p.Deployment = deployment
+			deploymentConfig.Images = append(deploymentConfig.Images, p.DeploymentConfig.Images...)
+			deploymentConfig.Env = NewEnvironment(deploymentConfig.Env, p.DeploymentConfig.Env)
+			p.DeploymentConfig = deploymentConfig
 		}
 	}
 	return nil
@@ -396,6 +424,26 @@ func AddServices(objects Objects, firstPortOnly bool) Objects {
 			if svc != nil {
 				svcs = append(svcs, svc)
 			}
+		case *kappsv1.Deployment:
+			svc := addService(t.Spec.Template.Spec.Containers, t.ObjectMeta, t.Spec.Template.Labels, firstPortOnly)
+			if svc != nil {
+				svcs = append(svcs, svc)
+			}
+		case *extensionsv1beta1.Deployment:
+			svc := addService(t.Spec.Template.Spec.Containers, t.ObjectMeta, t.Spec.Template.Labels, firstPortOnly)
+			if svc != nil {
+				svcs = append(svcs, svc)
+			}
+		case *kappsv1beta1.Deployment:
+			svc := addService(t.Spec.Template.Spec.Containers, t.ObjectMeta, t.Spec.Template.Labels, firstPortOnly)
+			if svc != nil {
+				svcs = append(svcs, svc)
+			}
+		case *kappsv1beta2.Deployment:
+			svc := addService(t.Spec.Template.Spec.Containers, t.ObjectMeta, t.Spec.Template.Labels, firstPortOnly)
+			if svc != nil {
+				svcs = append(svcs, svc)
+			}
 		case *kappsv1.DaemonSet:
 			svc := addService(t.Spec.Template.Spec.Containers, t.ObjectMeta, t.Spec.Template.Labels, firstPortOnly)
 			if svc != nil {
@@ -510,7 +558,7 @@ func (a *acceptNonExistentImageStream) Accept(from interface{}) bool {
 	if len(is.Namespace) > 0 {
 		namespace = is.Namespace
 	}
-	imgstrm, err := a.getter.ImageStreams(namespace).Get(is.Name, metav1.GetOptions{})
+	imgstrm, err := a.getter.ImageStreams(namespace).Get(context.TODO(), is.Name, metav1.GetOptions{})
 	if err == nil && imgstrm != nil {
 		klog.V(4).Infof("acceptor determined that imagestream %s in namespace %s exists so don't accept: %#v", is.Name, namespace, imgstrm)
 		return false
@@ -559,7 +607,7 @@ func (a *acceptNonExistentImageStreamTag) Accept(from interface{}) bool {
 	if len(ist.Namespace) > 0 {
 		namespace = ist.Namespace
 	}
-	tag, err := a.getter.ImageStreamTags(namespace).Get(ist.Name, metav1.GetOptions{})
+	tag, err := a.getter.ImageStreamTags(namespace).Get(context.TODO(), ist.Name, metav1.GetOptions{})
 	if err == nil && tag != nil {
 		klog.V(4).Infof("acceptor determined that imagestreamtag %s in namespace %s exists so don't accept: %#v", ist.Name, namespace, tag)
 		return false
